<?php
/**
 * @file
 * Contains \Drupal\foundation_sites\zurb_foundationLibrarySettingsForm
 */
namespace Drupal\foundation_sites;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure foundation_sites settings for this site.
 */
class zurb_foundationLibrarySettingsForm extends ConfigFormBase {

  public function getFormId() {
    return 'foundation_sites_admin_settings';
  }
  /** 
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'foundation_sites.settings',
    ];
  }

  /** 
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('foundation_sites.settings');
	
    $themes = \Drupal::service('theme_handler')->listInfo();
    $active_themes = array();
    foreach ($themes as $key => $theme) {
      if ($theme->status) {
        $active_themes[$key] = $theme->info['name'];
      }
    }
    // Load from CDN
    $form['cdn'] = array(
      '#type' => 'fieldset',
      '#title' => t('Load Boostrap from CDN'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
	$data = _foundation_sites_data();
    $cdn_options =  json_decode( $data );
    $versions = array_keys(_foundation_sites_object_to_array($cdn_options->zurb_foundation));
    $options = array_combine($versions, $versions);
    array_unshift( $options, 'Load locally' );
    $form['cdn']['zurb_foundation'] = array(
      '#type' => 'select',
      '#title' => t('Select zurb_foundation version to load via CDN, non for local library'),
      '#options' => $options,
      '#default_value' => $config->get('cdn.zurb_foundation'),
    );
    $form['cdn']['cdn_options'] = array(
      '#type' => 'hidden', 
	  '#value' => $data
	);
	// Production or minimized version
    $form['minimized'] = array(
      '#type' => 'fieldset',
      '#title' => t('Minimized, Non-minimized, or Composer version'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['minimized']['minimized_options'] = array(
      '#type' => 'radios',
      '#title' => t('Choose minimized, non-minimized, or composer version.'),
      '#options' => array(
        0 => t('Use non minimized libraries (Development)'),
        1 => t('Use minimized libraries (Production)'),
        2 => t('Use composer installed libraries'),      ),
      '#default_value' => $config->get('minimized.options'),
    );
    // Per-theme visibility.
    $form['theme'] = array(
      '#type' => 'fieldset',
      '#title' => t('Themes Visibility'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['theme']['theme_visibility'] = array(
      '#type' => 'radios',
      '#title' => t('Activate on specific themes'),
      '#options' => array(
        0 => t('All themes except those listed'),
        1 => t('Only the listed themes'),
      ),
      '#default_value' => $config->get('theme.visibility'),
    );
    $form['theme']['theme_themes'] = array(
      '#type' => 'select',
      '#title' => 'List of themes where library will be loaded.',
      '#options' => $active_themes,
      '#multiple' => TRUE,
      '#default_value' => $config->get('theme.themes'),
      '#description' => t("Specify in which themes you wish the library to load."),
    );
    // Per-path visibility.
    $form['url'] = array(
      '#type' => 'fieldset',
      '#title' => t('Activate on specific URLs'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['url']['url_visibility'] = array(
      '#type' => 'radios',
      '#title' => t('Load zurb_foundation on specific pages'),
      '#options' => array(0 => t('All pages except those listed'), 1 => t('Only the listed pages')),
      '#default_value' => $config->get('url.visibility'),
    );
    $form['url']['url_pages'] = array(
      '#type' => 'textarea',
      '#title' => '<span class="element-invisible">' . t('Pages') . '</span>',
      '#default_value' => _foundation_sites_array_to_string($config->get('url.pages')),
      '#description' => t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>')),
    );

    // Files settings.
    $form['files'] = array(
      '#type' => 'fieldset',
      '#title' => t('Files Settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['files']['types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Select which files to load from the library. By default you should check both, but in some cases you will need to load only CSS or JS zurb_foundation files.'),
      '#options' => array(
        'css' => t('CSS files'),
        'js' => t('Javascript files'),
      ),
      '#default_value' => $config->get('files.types'),
    );

    return parent::buildForm($form, $form_state);
  }

  /** 
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('foundation_sites.settings')
      ->set('theme.visibility', $form_state->getValue('theme_visibility'))
      ->set('theme.themes', $form_state->getValue('theme_themes'))
      ->set('url.visibility', $form_state->getValue('url_visibility'))
      ->set('url.pages', _foundation_sites_string_to_array($form_state->getValue('url_pages')))
      ->set('minimized.options', $form_state->getValue('minimized_options'))
      ->set('cdn.zurb_foundation', $form_state->getValue('zurb_foundation'))
      ->set('cdn.options', $form_state->getValue('cdn_options'))
      ->set('files.types', $form_state->getValue('types'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}

/**
 * Replaces CDN version options.
 * This is while find uptodate solution for CDN Version options
 */
function _foundation_sites_data() {

  return '{
  "timestamp": "2015-11-09T18:54:50.335Z",
  "zurb_foundation": {
    "4.1.1": {
      "css": "//stackpath.zurb_foundationcdn.com/zurb_foundation/4.1.1/css/zurb_foundation.min.css",
      "js": [
        "//cdnjs.cloudflare.com/ajax/libs/popper.js/1.11.0/umd/popper.min.js",
        "//stackpath.zurb_foundationcdn.com/zurb_foundation/4.1.1/js/zurb_foundation.min.js"
      ]
    },
    "4.0.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/4.0.0/css/zurb_foundation.min.css",
      "js": [
        "//cdnjs.cloudflare.com/ajax/libs/popper.js/1.11.0/umd/popper.min.js",
        "//maxcdn.zurb_foundationcdn.com/zurb_foundation/4.0.0/js/zurb_foundation.min.js"
      ]
    },
    "3.3.7": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.7/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.7/js/zurb_foundation.min.js"
    },
    "3.3.6": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.6/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.6/js/zurb_foundation.min.js"
    },
    "3.3.5": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.5/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.5/js/zurb_foundation.min.js"
    },
    "3.3.4": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.4/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.4/js/zurb_foundation.min.js"
    },
    "3.3.3": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.3/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.3/js/zurb_foundation.min.js"
    },
    "3.3.2": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.2/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.2/js/zurb_foundation.min.js"
    },
    "3.3.1": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.1/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.1/js/zurb_foundation.min.js"
    },
    "3.3.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.0/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.3.0/js/zurb_foundation.min.js"
    },
    "3.2.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.2.0/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.2.0/js/zurb_foundation.min.js"
    },
    "3.1.1": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.1.1/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.1.1/js/zurb_foundation.min.js"
    },
    "3.1.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.1.0/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.1.0/js/zurb_foundation.min.js"
    },
    "3.0.3": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.3/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.3/js/zurb_foundation.min.js"
    },
    "3.0.2": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.2/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.2/js/zurb_foundation.min.js"
    },
    "3.0.1": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.1/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.1/js/zurb_foundation.min.js"
    },
    "3.0.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.0/css/zurb_foundation.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.0/js/zurb_foundation.min.js"
    },
    "3.0.0-noicons": {
      "css": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.0/css/zurb_foundation.no-icons.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/zurb_foundation/3.0.0/js/zurb_foundation.min.js"
    },
    "2.3.2": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.2/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.2/js/zurb_foundation.min.js"
    },
    "2.3.2-noicons": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.2/css/zurb_foundation-combined.no-icons.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.2/js/zurb_foundation.min.js"
    },
    "2.3.1": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.1/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.1/js/zurb_foundation.min.js"
    },
    "2.3.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.0/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.3.0/js/zurb_foundation.min.js"
    },
    "2.2.2": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.2/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.2/js/zurb_foundation.min.js"
    },
    "2.2.2-noresponsible": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.2/css/zurb_foundation.min.nr.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.2/js/zurb_foundation.min.js"
    },

    "2.2.1": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.1/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.1/js/zurb_foundation.min.js"
    },
    "2.2.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.0/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.2.0/js/zurb_foundation.min.js"
    },
    "2.1.1": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.1.1/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.1.1/js/zurb_foundation.min.js"
    },
    "2.1.0": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.1.0/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.1.0/js/zurb_foundation.min.js"
    },
    "2.0.4": {
      "css": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.0.4/css/zurb_foundation-combined.min.css",
      "js": "//maxcdn.zurb_foundationcdn.com/twitter-zurb_foundation/2.0.4/js/zurb_foundation.min.js"
    }
  },
  "fontawesome": {
    "4.4.0": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.4.0/css/font-awesome.min.css",
    "4.2.0": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.2.0/css/font-awesome.min.css",
    "4.1.0": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.1.0/css/font-awesome.min.css",
    "4.0.3": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.0.3/css/font-awesome.min.css",
    "4.0.2": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.0.2/css/font-awesome.min.css",
    "4.0.1": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.0.1/css/font-awesome.min.css",
    "4.0.0": "//maxcdn.zurb_foundationcdn.com/font-awesome/4.0.0/css/font-awesome.min.css",
    "3.2.1": "//maxcdn.zurb_foundationcdn.com/font-awesome/3.2.1/css/font-awesome.min.css"
  }
}';
}

/**
 * Load CDN version optios.
 */
function _foundation_sites_cdn_versions() {
  static $uri = 'http://netdna.zurb_foundationcdn.com/data/zurb_foundationcdn.json';
  $json_response = NULL;
  try {
    $client = \Drupal::httpClient();
    $response = $client->get($uri, array('headers' => array('Accept' => 'text/plain')));
	$data = (string) $response->getBody();
    if (empty($data)) {
      return FALSE;
    }
  }
  catch (RequestException $e) {
    watchdog_exception('foundation_sites', $e->getMessage());
    return FALSE;
  }
  return $data;
}

?>